@@ -12,15 +12,32 @@ gof <- function(object){
 	}	
 		brks <- quantile(p, seq(0, 1, length=11))
 		g <- cut(p, br = brks, include.lowest = TRUE)
-		O <- tapply(y,g,sum)
-		E <- tapply(p*w,g,sum)
+		
+		O.cases <- tapply(w*y,g,sum)
+		O.controls <- tapply(w*(1-y),g,sum)
+		
+		E.cases <- tapply(p*w,g,sum)
+		E.controls <- tapply((1-p)*w,g,sum)
 
-		result <- data.frame(O=O,E=E)
-	    chisq = sum((O-E)^2/E)
-	    P = 1 - pchisq(chisq, df=8)
+		result <- list(
+							cases=data.frame(O=O.cases,E=E.cases), 
+							controls=data.frame(O=O.controls, E=E.controls))
+							
+		chisq = sum((O.cases-E.cases)^2/E.cases+(O.controls-E.controls)^2/E.controls)
 
+	    if(all(w==1)){
+	        P = 1 - pchisq(chisq, df=8)
+	        list(table = result, chisq = chisq, p.value = P)
+	     }
+	     else{
+	     	# ADJUSTED F, ARCHER 2007
+	     	df.num <- 9
+	     	df.denom <- length(y)-8
+	     	chisq <- chisq*((length(y)-8)/(10*length(y)))
+	     	P <- 1 - pf(chisq,df.num,df.denom)
+	     	list(table = result, F = chisq, p.value = P)
+	     }
 
-list(table = result, chisq = chisq, p.value = P)
 }
 
 EO <- function(object, index=NULL,level=.95){
@@ -44,6 +61,9 @@ EO <- function(object, index=NULL,level=.95){
   					EtoO = E/O,
   				    lowerCI = lower, 
   				    upperCI = upper)
- 
- results
+  				    
+  	if(nrow(results)>1)
+ 		row.names(results) <- levels(index)
+
+results
 }
\ No newline at end of file
